
%macro calcPredBIA(useData=);
	data _null_;
  		dsid=open("&useData");
		call symput('chkID', 	varnum(dsid,'id'));
  		call symput('chkAge', 	varnum(dsid,'age'));
		call symput('chkEthnicity',	varnum(dsid,'ethnicity'));
		call symput('chkHt', 	varnum(dsid,'ht'));
		call symput('chkWt', 	varnum(dsid,'wt'));
		call symput('chkArml', 	varnum(dsid,'arml'));
		call symput('chkLeg', 	varnum(dsid,'leg'));
		call symput('chkArmc', 	varnum(dsid,'armc'));
		call symput('chkWaist', varnum(dsid,'waist'));
		call symput('chkCalf', 	varnum(dsid,'calf'));
		call symput('chkThic', 	varnum(dsid,'thic'));
		call symput('chkTri', 	varnum(dsid,'tri'));
		call symput('chkSub', 	varnum(dsid,'sub'));
		call symput('chkMenses',varnum(dsid,'menses'));
		call symput('chkResist',varnum(dsid,'resist'));
		call symput('chkReact',	varnum(dsid,'react'));
		call symput('chkSex',	varnum(dsid,'sex'));
	run;


	%if &chkID=0 | &chkAge=0 | &chkEthnicity=0 | &chkHt=0 | &chkWt=0 | &chkArml=0 | &chkLeg=0 | &chkArmc=0 |
			&chkWaist=0 | &chkCalf=0 | &chkThic=0 | &chkTri=0 | &chkSub=0 | (&chkMenses=0 and %upcase(sex)=F)| &chkResist=0 | &chkReact=0 | &chkSex=0
			%then %do; %let stopExe=1; %end;
			%else %do; %let stopExe=0;
	%end;

	%if &stopExe=1 %then %do;
		%put ERROR: Dataset error, predicted body fat was not calculated. ;

		%if &chkID=0	%then %put ERROR: Variable ID does not exist. ;
		%if &chkAge=0 	%then %put ERROR: Variable AGE does not exist. ;
		%if &chkEthnicity=0	%then %put ERROR: Variable ETHNICITY does not exist. ;
		%if &chkHt=0 	%then %put ERROR: Variable HT does not exist. ;
		%if &chkWt=0 	%then %put ERROR: Variable WT does not exist. ;
		%if &chkArml=0 	%then %put ERROR: Variable ARML does not exist. ;
		%if &chkLeg=0 	%then %put ERROR: Variable LEG does not exist. ;
		%if &chkArmc=0 	%then %put ERROR: Variable ARMC does not exist. ;
		%if &chkWaist=0 %then %put ERROR: Variable WAIST does not exist. ;
		%if &chkCalf=0 	%then %put ERROR: Variable CALF does not exist. ;
		%if &chkThic=0 	%then %put ERROR: Variable THIC does not exist. ;
		%if &chkTri=0 	%then %put ERROR: Variable TRI does not exist. ;
		%if &chkSub=0 	%then %put ERROR: Variable SUB does not exist. ;
		%if &chkMenses=0 and %upcase(sex)=F %then %put ERROR: Variable MENSES does not exist. ;
		%if &chkResist=0 %then %put ERROR: Variable RESIST does not exist. ;
		%if &chkReact=0 %then %put ERROR: Variable REACT does not exist. ;
		%if &chkSex=0 %then %put ERROR: Variable SEX does not exist. ;

	%goto exit;
	%end;


	%if &chkEthnicity ^=0 | &chkMenses ^=0 %then %do;
		data makedata;
			set &usedata(keep=
				%if &chkMenses ^=0 %then %do; menses %end;
				%if &chkEthnicity ^=0 %then %do; ethnicity %end;);
			%if &chkMenses ^=0 %then %do;
				chkMensesUnit=(menses in (0, 1));
			%end;
			%if &chkEthnicity ^=0 %then %do;
				chkEthnicityUnit=(upcase(ethnicity) in ("W", "B", "M", "O"));
			%end;
		run;

		proc sql noprint;
			select 
				%if &chkMenses ^=0 and &chkEthnicity ^=0 %then %do;
					min(chkMensesUnit), min(chkEthnicityUnit) into :chkMensesUnit, :chkEthnicityUnit
				%end;
					%else %if &chkMenses ^=0 %then %do;
						min(chkMensesUnit) into :chkMensesUnit
					%end;
					%else %if &chkEthnicity ^=0 %then %do;
						min(chkEthnicityUnit) into :chkEthnicityUnit
					%end;
				%end;
				from makedata;
		quit;

	data coefMod;
		set macrolib.ABCC_BIA_DATA;
	run;

	PROC SORT DATA=&USEDATA;
		BY ID;
	RUN;


	****Body Fat Prediction****;
	*********
	*Model A;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModA(drop=_name_ _label_) prefix=_MA;
	    id parameter;
	    var MBIAModA;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModA(drop=_name_ _label_) prefix=_FA;
	    id parameter;
	    var FBIAModA;
	run;
	*Merge "A" data sets;
	proc sql;
		create table coefModA2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, 
				((ht**2)/resist) as ri
		from coefMModA as m, coefFModA as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODA COEFFMODA;
	RUN;

	*Calculate Predicted body fat;
	data coefModA;
		set coefModA2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 
				predBIABF_A =	
							_MAIntercept		+											
							_MAadage2tri3R		*	(	adult	*	(age**(2))	*	(tri**(-3)) 		)	+
							_MAadage3Rri3R		*	(	adult	*	(age**(-3))	*	(ri**(-3)) 			)	+
							_MAadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))  		)	+
							_MAadage3tri3R		*	(	adult	*	(age**(3))	*	(tri**(-3))  		)	+
							_MAadwt3			*	(	adult	*	(wt**(3))							)	+
							_MAage2Rthic3		*	(	age**(-2)	*	(thic**(3))						)	+
							_MAageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+
							_MAageRcalf3		*	(	age**(-1)	*	(calf**(3))						)	+
							_MAageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+
							_MAageRri2			*	(	age**(-1)	*	(ri**(2))						)	+
							_MAageRsub			*	(	age**(-1)	*	(sub)							)	+
							_MAageRtri			*	(	age**(-1)	*	(tri)							)	+
							_MAageRwaist2		*	(	age**(-1)	*	(waist**(2))					)	+
							_MAageRwaist3		*	(	age**(-1)	*	(waist**(3))					)	+
							_MAageri2R			*	(	age		*	(ri**(-2))							)	+
							_MAagewaist3R		*	(	age		*	(waist**(-3))						)	+
							_MAarml3			*	(	arml**(3)										)	+
							_MAbkarmc3			*	(	bk	*	(armc**(3))								)	+
							_MAbkreact3			*	(	bk	*	(react**(3))							)	+
							_MAbkresist2R		*	(	bk	*	(resist**(-2))							)	+
							_MAbmiR				*	(	bmi**(-1)										)	+
							_MAcalf2			*	(	calf**(2)										)	+
							_MAmxadtri3			*	(	mx	*	(adult	*	(tri**(3))	)				)	+
							_MAreact			*	(	react											)	+
							_MAresist2			*	(	resist**(2)										)	+
							_MAresist3			*	(	resist**(3)										)	+
							_MAsubR				*	(	sub**(-1)										)	+
							_MAtri				*	(	tri												) 	+
							_MAtriR				*	(	tri**(-1)										)	+
							_MAwaist			*	(	waist											)								
							
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 
				predBIABF_A = 
							_FAIntercept		+	
							_FABMI				*	(bmi												)	+								
							_FAageRri3			*	(	age**(-1)	*	(ri**(3))						)	+
							_FAageRtri2			*	(	age**(-1)	*	(tri**(2))						)	+
							_FAageresist3		*	(	age	*	(resist**(3))							)	+	
							_FAageri3R			*	(	age	*	(ri**(-3))								)	+	
							_FAagesub2R			*	(	age	*	(sub**(-2))								)	+	
							_FAbkreact2			*	(	bk	*	(react**(2))							)	+	
							_FAbkresist2R		*	(	bk	*	(resist**(-2))							)	+	
							_FAbktriR			*	(	bk	*	(tri**(-1))								)	+	
							_FAbmiR				*	(	bmi**(-1)										)	+			
							_FAcalf3			*	(	calf**(3)										)	+			
							_FAmenswaist3R		*	(	menses	*	(waist**(-3))						)	+	
							_FAresist			*	(	resist											)	+				
							_FAresistR			*	(	resist**(-1)									)	+			
							_FAsubR				*	(	sub**(-1)										)	+			
							_FAthic3			*	(	thic**(3)										)	+			
							_FAtri				*	(	tri												)	+				
							_FAtriR				*	(	tri**(-1)										)	+			
							_FAwaistR			*	(	waist**(-1)										)				
							
			

					;
	run;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODA2;
	RUN;

	proc sql;
		create table MOD1 as
		select a.predBIABF_a, a.id
		from coefModA as a;
	quit;

	PROC SORT DATA=MOD1;
		BY ID;
	RUN;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODA;
	RUN;

	
	*********
	*Model B;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModB(drop=_name_ _label_) prefix=_MB;
	    id parameter;
	    var MBIAModB;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModB(drop=_name_ _label_) prefix=_FB;
	    id parameter;
	    var FBIAModB;
	run;
	*Merge "B" data sets;
	proc sql;
		create table coefModB2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModB as m, coefFModB as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODB COEFFMODB;
	RUN;

	*Calculate Predicted body fat;
	data coefModB;
		set coefModB2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_B=	
							_MBIntercept		+	
							_MBBMI				*	(	BMI												)	+					
							_MBadage3Rresist3	*	(	adult	*	(age**(-3))	*	(resist**(3))		)	+
							_MBadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MBadage3tri3R		*	(	adult	*	(age**(3))	*	(tri**(-3))			)	+
							_MBadwt3			*	(	adult	*	(wt**(3))							)	+
							_MBage2Rthic3		*	(	age**(-2)	*	(thic**(3))						)	+
							_MBageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+
							_MBageRcalf3		*	(	age**(-1)	*	(calf**(3))						)	+
							_MBageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+
							_MBageRri2			*	(	age**(-1)	*	(ri**(2))						)	+
							_MBageRsub			*	(	age**(-1)	*	(sub)							)	+
							_MBageRtri			*	(	age**(-1)	*	(tri)							)	+
							_MBageRwaist2		*	(	age**(-1)	*	(waist**(2))					)	+
							_MBageRwaist3		*	(	age**(-1)	*	(waist**(3))					)	+
							_MBageri2R			*	(	age		*	(ri**(-2))							)	+
							_MBagewaist3R		*	(	age		*	(waist**(-3))						)	+
							_MBbkarmc3			*	(	bk		*	(armc**(3))							)	+
							_MBbkreact3			*	(	bk		*	(react**(3))						)	+
							_MBbkresist2R		*	(	bk		* 	(resist**(-2))						)	+
							_MBbkri				*	(	bk		*	(ri)								)	+
							_MBbkri2			*	(	bk		*	(ri**(2))							)	+
							_MBbmiR				*	(	bmi**(-1)										)	+
							_MBcalf3			*	(	calf**(3)										)	+
							_MBmxadtri3			*	(	mx		*	(adult)		*	(tri**(3))			)	+
							_MBreact			*	(	react											)	+
							_MBresist3			*	(	resist**(3)										)	+
							_MBsubR				*	(	sub**(-1)										)	+
							_MBtri				*	(	tri												)	+
							_MBtriR				*	(	tri**(-1)										)	+
							_MBwaist			*	(	waist											)					
							
					;
				

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then 

				predBIABF_B=	
							_FBIntercept		+	
							_FBBMI				*	(	bmi												)	+									
							_FBadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FBage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FBage3Rtri			*	(	age**(-3)	*	(tri)							)	+			
							_FBageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FBageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_FBageRtri2			*	(	age**(-1)	*	(tri**(2))						)	+		
							_FBagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_FBageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FBagesub2R			*	(	age		*	(sub**(-2))							)	+			
							_FBbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FBbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FBbktriR			*	(	bk		*	(tri**(-1))							)	+			
							_FBbmiR				*	(	bmi**(-1)										)	+					
							_FBcalf3			*	(	calf**(3)										)	+					
							_FBreactR			*	(	react**(-1)										)	+					
							_FBresist2R			*	(	resist**(-2)									)	+					
							_FBresistR			*	(	resist**(-1)									)	+					
							_FBthic3			*	(	thic**(3)										)	+					
							_FBtri				*	(	tri												)	+						
							_FBtriR				*	(	tri**(-1)										)	+					
							_FBwaistR			*	(	waist**(-1)										)						
							
					;
	run;	

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODB2;
	RUN;
	
	proc sql;
		create table MOD2 as
		select a.predBIABF_B, a.ID
		from coefModB as A;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODB;
	RUN;

	PROC SORT DATA=MOD2; 
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD1 MOD2;
		BY ID;
	RUN;


	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD1 MOD2;
	RUN;

	*********
	*Model C;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModC(drop=_name_ _label_) prefix=_MC;
	    id parameter;
	    var MBIAModC;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModC(drop=_name_ _label_) prefix=_FC;
	    id parameter;
	    var FBIAModC;
	run;
	*Merge "C" data sets;
	proc sql;
		create table coefModC2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModC as m, coefFModC as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODC COEFFMODC;
	RUN;

	*Calculate Predicted body fat;
	data coefModC;
		set coefModC2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_C=	
							_MCIntercept		+								
							_MCadage2Rsub2R		*	(	adult	*	(age**(-2))	*	(sub**(-2))			)	+
							_MCadage3Rresist3	*	(	adult	*	(age**(-3))	*	(resist**(3))		)	+
							_MCadage3Rri3R		*	(	adult	*	(age**(-3))	*	(ri**(-3))			)	+
							_MCadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MCadage3sub2R		*	(	adult	*	(age**(3))	*	(sub**(-2))			)	+
							_MCadagecalf3		*	(	adult	*	(age)		*	(calf**(3))			)	+	
							_MCadageht3			*	(	adult	*	(age)		*	(ht**(3))			)	+	
							_MCadwaist2			*	(	adult	*	(waist**(2))						)	+			
							_MCadwt2			*	(	adult	*	(wt**(2))							)	+			
							_MCage2Rarmc3		*	(	age**(-2)	*	(armc**(3))						)	+		
							_MCage2Rsub3		*	(	age**(-2)	*	(sub**(3))						)	+		
							_MCage3Rri3R		*	(	age**(-3)	*	(ri**(-3))						)	+		
							_MCage3Rsub3		*	(	age**(-3)	*	(sub**(3))						)	+		
							_MCage3Rwt3R		*	(	age**(-3)	*	(wt**(-3))						)	+		
							_MCage3sub3			*	(	age**(3)	*	(sub**(3))						)	+		
							_MCageRcalf3		*	(	age**(-1)	*	(calf**(3))						)	+		
							_MCageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MCageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MCageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_MCageRthic2		*	(	age**(-1)	*	(thic**(2))						)	+		
							_MCageRwaist2		*	(	age**(-1)	*	(waist**(2))					)	+		
							_MCagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_MCageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MCagesubR			*	(	age		*	(sub**(-1))							)	+			
							_MCagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_MCbkadwt3R			*	(	bk		*	(adult)		*	(wt**(-3))			)	+	
							_MCbkarmc3			*	(	bk		*	(armc**(3))							)	+			
							_MCbkarmc3R			*	(	bk		*	(armc**(-3))						)	+			
							_MCbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MCbkri2			*	(	bk		*	(ri**(2))							)	+			
							_MCbksubR			*	(	bk		*	(sub**(-1))							)	+			
							_MCbmiR				*	(	bmi**(-1)										)	+					
							_MCht2				*	(	ht**(2)											)	+					
							_MCmtadwt3R			*	(	mt		*	(adult)		*	(wt**(-3))			)	+	
							_MCmtarmc3			*	(	mt		*	(armc**(3))							)	+			
							_MCmtht3			*	(	mt		*	(ht**(3))							)	+			
							_MCmtsub2R			*	(	mt		*	(sub**(-2))							)	+			
							_MCmtwt3R			*	(	mt		*	(wt**(-3))							)	+			
							_MCmxadreact3R		*	(	mx		*	(adult)		*	(react**(-3))		)	+	
							_MCmxadri3R			*	(	mx		*	(adult)		*	(ri**(-3))			)	+	
							_MCmxreact3			*	(	mx		*	(react**(3))						)	+			
							_MCmxreact3R		*	(	mx		*	(react**(-3))						)	+			
							_MCmxsub3			*	(	mx		*	(sub**(3))							)	+			
							_MCreact			*	(	react											)	+					
							_MCreactR			*	(	react**(-1)										)	+					
							_MCresist			*	(	resist											)	+					
							_MCresist2			*	(	resist**(2)										)	+					
							_MCsubR				*	(	sub**(-1)										)	+					
							_MCthic				*	(	thic											)	+					
							_MCthicR			*	(	thic**(-1)										)	+					
							_MCwaist			*	(	waist											)							
							
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_C=	
							_FCIntercept		+								
							_FCBMI				*	(	bmi												)	+						
							_FCadage2Rwt3R		*	(	adult	*	(age**(-2))	*	(wt**(-3))			)	+
							_FCadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FCage3Rarmc3		*	(	age**(-3)	*	(armc**(3))						)	+		
							_FCage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FCageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FCageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_FCageresist3		*	(	age		*	(resist**(3))						)	+			
							_FCageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FCagesub2R			*	(	age		*	(sub**(-2))							)	+			
							_FCarmc				*	(	armc											)	+						
							_FCbkbmiR			*	(	bk		*	(bmi**(-1))							)	+			
							_FCbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FCbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FCbksubR			*	(	bk		*	(sub**(-1))							)	+			
							_FCbmiR				*	(	bmi**(-1)										)	+					
							_FCcalf3			*	(	calf**(3)										)	+					
							_FCreactR			*	(	react**(-1)										)	+					
							_FCresist			*	(	resist											)	+						
							_FCresistR			*	(	resist**(-1)									)	+					
							_FCsub				*	(	sub												)	+						
							_FCthic2			*	(	thic**(2)										)	+					
							_FCwaist			*	(	waist											)	+						
							_FCwaistR			*	(	waist**(-1)										)						
							

					;
	run;	


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODC2 ;
	RUN;

	
	proc sql;
		create table MOD3 as
		select a.predBIABF_C, a.ID
		from coefModC as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODC;
	RUN;

	PROC SORT DATA=MOD3;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD3;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD3;
	RUN;

	*********
	*Model D;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModD(drop=_name_ _label_) prefix=_MD;
	    id parameter;
	    var MBIAModD;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModD(drop=_name_ _label_) prefix=_FD;
	    id parameter;
	    var FBIAModD;
	run;
	*Merge "D" data sets;
	proc sql;
		create table coefModD2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModD as m, coefFModD as f, &usedata as t;
	quit;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODD COEFFMODD;
	RUN;

	*Calculate Predicted body fat;
	data coefModD;
		set coefModD2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then

				predBIABF_D=
							_MDIntercept		+								
							_MDBMI				*	(	bmi												)	+						
							_MDadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MDageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MDageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MDageRtri			*	(	age**(-1)	*	(tri)							)	+			
							_MDageRwaist3		*	(	age**(-1)	*	(waist**(3))					)	+		
							_MDageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MDagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_MDbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MDbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_MDbkri				*	(	bk		*	(ri)								)	+				
							_MDbkri2			*	(	bk		*	(ri**(2))							)	+			
							_MDbmiR				*	(	bmi**(-1)										)	+					
							_MDcalf3			*	(	calf**(3)										)	+					
							_MDreact			*	(	react											)	+						
							_MDreactR			*	(	react**(-1)										)	+					
							_MDresist3			*	(	resist**(3)										)	+					
							_MDtri				*	(	tri												)	+						
							_MDtriR				*	(	tri**(-1)										)	+					
							_MDwaist			*	(	waist											)							
							
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_D=	
							_FDIntercept		+								
							_FDBMI				*	(	bmi												)	+						
							_FDadage2Rbmi3R		*	(	adult	*	(age**(-2))	*	(bmi**(-3))			)	+
							_FDage3Rwaist3		*	(	age**(-3)	*	(waist**(3))					)	+		
							_FDageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_FDageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FDageRtri2			*	(	age**(-1)	*	(tri**(2))						)	+		
							_FDagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_FDageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FDbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FDbkri				*	(	bk		*	(ri)								)	+				
							_FDbmiR				*	(	bmi**(-1)										)	+					
							_FDresist			*	(	resist											)	+						
							_FDresistR			*	(	resist**(-1)									)	+					
							_FDthic3			*	(	thic**(3)										)	+					
							_FDtri				*	(	tri												)	+						
							_FDtriR				*	(	tri**(-1)										)	+					
							_FDwaistR			*	(	waist**(-1)										)						
							
					;
	run;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODD2;
	RUN;

	proc sql;
		create table MOD4 as
		select a.predBIAbf_d, A.ID
		from coefModD as A;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODD;
	RUN;

	PROC SORT DATA=MOD4;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD4;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD4;
	RUN;

	*********
	*Model E;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModE(drop=_name_ _label_) prefix=_ME;
	    id parameter;
	    var MBIAModE;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModE(drop=_name_ _label_) prefix=_FE;
	    id parameter;
	    var FBIAModE;
	run;
	*Merge "E" data sets;
	proc sql;
		create table coefModE2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModE as m, coefFModE as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODE COEFFMODE;
	RUN;

	*Calculate Predicted body fat;
	data coefModE;
		set coefModE2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_E=	
							_MEIntercept		+								
							_MEadage3Rbmi3		*	(	adult	*	(age**(-3))	*	(bmi**(3))			)	+
							_MEadage3Rresist3	*	(	adult	*	(age**(-3))	*	(resist**(3))		)	+
							_MEadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MEadage3wt3R		*	(	adult	*	(age**(3))	*	(wt**(-3))			)	+
							_MEadageht3			*	(	adult	*	(age)		*	(ht**(3))			)	+	
							_MEadcalf3			*	(	adult	*	(calf**(3))							)	+			
							_MEadht3			*	(	adult	*	(ht**(3))							)	+			
							_MEage2Rarmc3		*	(	age**(-2)	*	(armc**(3))						)	+		
							_MEage3Rarmc3R		*	(	age**(-3)	*	(armc**(-3))					)	+		
							_MEage3Rht3R		*	(	age**(-3)	*	(ht**(-3))						)	+		
							_MEage3Rri3R		*	(	age**(-3)	*	(ri**(-3))						)	+		
							_MEage3bmi3			*	(	age**(3)	*	(bmi**(3))						)	+		
							_MEage3react3R		*	(	age**(3)	*	(react**(-3))					)	+		
							_MEageRcalf3		*	(	age**(-1)	*	(calf**(3))						)	+		
							_MEageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MEageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MEageRthic2		*	(	age**(-1)	*	(thic**(2))						)	+		
							_MEageRwaist2		*	(	age**(-1)	*	(waist**(2))					)	+		
							_MEageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MEagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_MEbkadwt3R			*	(	bk		*	(adult)		*	(wt**(-3))			)	+	
							_MEbkarmc3			*	(	bk		*	(armc**(3))							)	+			
							_MEbkarmc3R			*	(	bk		*	(armc**(-3))						)	+			
							_MEbkcalf3			*	(	bk		*	(calf**(3))							)	+			
							_MEbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MEbkresist3R		*	(	bk		*	(resist**(-3))						)	+			 
							_MEbmiR				*	(	bmi**(-1)										)	+					
							_MEht				*	(	ht												)	+						
							_MEht2				*	(	ht**(2)											)	+					
							_MEmtadwt3R			*	(	mt		*	(adult)		*	(wt**(-3))			)	+	
							_MEmtri3			*	(	mt		*	(ri**(3))							)	+			
							_MEmxadri3			*	(	mx		*	(adult)		*	(ri**(3))			)	+	
							_MEmxadri3R			*	(	mx		*	(adult)		*	(ri**(-3))			)	+	
							_MEmxreact3			*	(	mx		*	(react**(3))						)	+			
							_MEmxreact3R		*	(	mx		*	(react**(-3))						)	+			
							_MEreact			*	(	react											)	+						
							_MEresist			*	(	resist											)	+						
							_MEresist2			*	(	resist**(2)										)	+					
							_MEriR				*	(	ri**(-1)										)	+					
							_MEthicR			*	(	thic**(-1)										)	+					
							_MEwaist			*	(	waist											)	+						
							_MEwaistR			*	(	waist**(-1)										)						
							
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_E=	
							_FEIntercept		+								
							_FEBMI				*	(	bmi												)	+						
							_FEadage2Rwt3R		*	(	adult	*	(age**(-2))	*	(wt**(-3))			)	+
							_FEage3Rarmc3		*	(	age**(-3)	*	(armc**(3))						)	+		
							_FEage3Rreact3R		*	(	age**(-3)	*	(react**(-3))					)	+		
							_FEage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FEage3Rwaist3		*	(	age**(-3)	*	(waist**(3))					)	+		
							_FEageRarmc3		*	(	age**(-1)	*	(armc**(3))						)	+		
							_FEageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_FEageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FEagearmc3R		*	(	age		*	(armc**(-3))						)	+			
							_FEageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FEarmc				*	(	armc											)	+						
							_FEbkarmcR			*	(	bk		*	(armc**(-1))						)	+			
							_FEbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FEbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FEbkri				*	(	bk		*	(ri)								)	+				
							_FEbkthicR			*	(	bk		*	(thic**(-1))						)	+			
							_FEbmiR				*	(	bmi**(-1)										)	+					
							_FEcalf3			*	(	calf**(3)										)	+					
							_FEreactR			*	(	react**(-1)										)	+					
							_FEresist			*	(	resist											)	+						
							_FEthic3			*	(	thic**(3)										)	+					
							_FEwaistR			*	(	waist**(-1)										)						
							
					;
	run;	
	
	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODE2;
	RUN;

	proc sql;
		create table MOD5 as
		select a.predBIAbf_E, a.ID
		from coefModE as A;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODE;
	RUN;

	PROC SORT DATA=MOD5;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD5;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD5;
	RUN;

	*********
	*Model F;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModF(drop=_name_ _label_) prefix=_MF;
	    id parameter;
	    var MBIAModF;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModF(drop=_name_ _label_) prefix=_FF;
	    id parameter;
	    var FBIAModF;
	run;
	*Merge "F" data sets;
	proc sql;
		create table coefModF2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModF as m, coefFModF as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODF COEFFMODF;
	RUN;

	*Calculate Predicted body fat;
	data coefModF;
		set coefModF2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_F= 	
							_MFIntercept		+								
							_MFBMI				*	(	BMI												)	+						
							_MFadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MFadagewt3			*	(	adult	*	(age)	*	(wt**(3))				)	+	
							_MFageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MFageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MFageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_MFageRtri			*	(	age**(-1)	*	(tri)							)	+			
							_MFageRwaist3		*	(	age**(-1)	*	(waist**(3))					)	+		
							_MFageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MFagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_MFbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MFbkri				*	(	bk		*	(ri)								)	+				
							_MFcalf3			*	(	calf**(3)										)	+					
							_MFreactR			*	(	react**(-1)										)	+					
							_MFsubR				*	(	sub**(-1)										)	+					
							_MFtri				*	(	tri												)	+						
							_MFtriR				*	(	tri**(-1)										)	+					
							_MFwaist			*	(	waist											)							
							
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then 

				predBIABF_F=	
							_FFIntercept		+						
							_FFBMI				*	(	bmi												)	+				
							_FFage3Rtri			*	(	age**(-3)	*	(tri)							)	+	
							_FFage3Rtri2		*	(	age**(-3)	*	(tri**(2))						)	+
							_FFageRri3			*	(	age**(-1)	*	(ri**(3))						)	+
							_FFageRsub			*	(	age**(-1)	*	(sub)							)	+	
							_FFageRtri2			*	(	age**(-1)	*	(tri**(2))						)	+
							_FFagebmi3R			*	(	age		*	(bmi**(-3))							)	+	
							_FFageri3R			*	(	age		*	(ri**(-3))							)	+	
							_FFagesub2R			*	(	age		*	(sub**(-2))							)	+	
							_FFbkresist2R		*	(	bk		*	(resist**(-2))						)	+	
							_FFbkresist3R		*	(	bk		*	(resist**(-3))						)	+	
							_FFbktriR			*	(	bk		*	(tri**(-1))							)	+	
							_FFbmiR				*	(	bmi**(-1)										)	+			
							_FFcalf3			*	(	calf**(3)										)	+			
							_FFresist2R			*	(	resist**(-2)									)	+			
							_FFresistR			*	(	resist**(-1)									)	+			
							_FFtri				*	(	tri												)	+				
							_FFtriR				*	(	tri**(-1)										)	+			
							_FFwaistR			*	(	waist**(-1)										)				
						
							;
	run;	

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODF2;
	RUN;
	
	proc sql;
		create table MOD6 as
		select a.predBIAbf_F, a.ID
		from coefModF as A;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODF;
	RUN;	


	PROC SORT DATA=MOD6;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD6;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD6;
	RUN;

	*********
	*Model G;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModG(drop=_name_ _label_) prefix=_MG;
	    id parameter;
	    var MBIAModG;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModG(drop=_name_ _label_) prefix=_FG;
	    id parameter;
	    var FBIAModG;
	run;
	*Merge "G" data sets;
	proc sql;
		create table coefModG2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModG as m, coefFModG as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODG COEFFMODG;
	RUN;

	*Calculate Predicted body fat;
	data coefModG;
		set coefModG2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_G=	
							_MGIntercept		+								
							_MGBMI				*	(	BMI												)	+						
							_MGadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MGadage3tri3R		*	(	adult	*	(age**(3))	*	(tri**(-3))			)	+
							_MGadagewt3			*	(	adult	*	(age)		*	(wt**(3))			)	+	
							_MGageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_MGageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MGageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MGageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_MGageRtri			*	(	age**(-1)	*	(tri)							)	+			
							_MGageRwaist3		*	(	age**(-1)	*	(waist**(3))					)	+		
							_MGageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MGagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_MGbkarmc3			*	(	bk		*	(armc**(3))							)	+			
							_MGbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MGbkri				*	(	bk		*	(ri)								)	+				
							_MGbkri2			*	(	bk		*	(ri**(2))							)	+			
							_MGreactR			*	(	react**(-1)										)	+					
							_MGresist3			*	(	resist**(3)										)	+					
							_MGsubR				*	(	sub**(-1)										)	+					
							_MGtri				*	(	tri												)	+						
							_MGtriR				*	(	tri**(-1)										)	+					
							_MGwaist			*	(	waist											)	
						

						;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_G=	
							_FGIntercept		+								
							_FGBMI				*	(	bmi												)	+						
							_FGadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FGage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FGage3Rtri			*	(	age**(-3)	*	(tri)							)	+			
							_FGageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FGageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_FGageRtri2			*	(	age**(-1)	*	(tri**(2))						)	+		
							_FGagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_FGageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FGagesub2R			*	(	age		*	(sub**(-2))							)	+			
							_FGbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FGbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FGbktriR			*	(	bk		*	(tri**(-1))							)	+			
							_FGbmiR				*	(	bmi**(-1)										)	+					
							_FGreactR			*	(	react**(-1)										)	+					
							_FGresist2R			*	(	resist**(-2)									)	+					
							_FGresistR			*	(	resist**(-1)									)	+					
							_FGtri				*	(	tri												)	+						
							_FGtriR				*	(	tri**(-1)										)	+					
							_FGwaistR			*	(	waist**(-1)										)						
						
						;
	run;		
	

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODG2;
	RUN;

	proc sql;
		create table MOD7 as
		select a.predBIAbf_G, a.ID
		from coefModG as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODG;
	RUN;


	PROC SORT DATA=MOD7;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD7;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD7;
	RUN;

	*********
	*Model H;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModH(drop=_name_ _label_) prefix=_MH;
	    id parameter;
	    var MBIAModH;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModH(drop=_name_ _label_) prefix=_FH;
	    id parameter;
	    var FBIAModH;
	run;


	*Merge "H" data sets;
	proc sql;
		create table coefModH2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModH as m, coefFModH as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODH COEFFMODH;
	RUN;

	*Calculate Predicted body fat;
	data coefModH;
		set coefModH2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then

				predBIABF_H=	
							_MHIntercept		+								
							_MHBMI				*	(	bmi												)	+						
							_MHadage3Rwt2R		*	(	adult	*	(age**(-3))	*	(wt**(-2))			)	+
							_MHadage3Rwt3R		*	(	adult	*	(age**(-3))	*	(wt**(-3))			)	+
							_MHadagewt3			*	(	adult	*	(age)		*	(wt**(3))			)	+	
							_MHadwt3			*	(	adult	*	(wt**(3))							)	+			
							_MHageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_MHageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MHageRresist3R		*	(	age**(-1)	*	(resist**(-3))					)	+		
							_MHageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MHageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_MHageRtri			*	(	age**(-1)	*	(tri)							)	+			
							_MHagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_MHageresist3		*	(	age		*	(resist**(3))						)	+			
							_MHageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MHbkarmc3			*	(	bk		*	(armc**(3))							)	+			
							_MHbkreact2			*	(	bk		*	(react**(2))						)	+			
							_MHbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_MHbmiR				*	(	bmi**(-1)										)	+					
							_MHreactR			*	(	react**(-1)										)	+					
							_MHresist			*	(	resist											)	+						
							_MHresist2			*	(	resist**(2)										)	+					
							_MHsubR				*	(	sub**(-1)										)	+					
							_MHtri				*	(	tri												)	+						
							_MHtriR				*	(	tri**(-1)										)						
							

					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then 

				predBIABF_H=	
							_FHIntercept		+								
							_FHBMI				*	(	bmi												)	+						
							_FHadage2Rwt3R		*	(	adult	*	(age**(-2))	*	(wt**(-3))			)	+
							_FHage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FHage3Rsub			*	(	age**(-3)	*	(sub)							)	+			
							_FHage3Rtri			*	(	age**(-3)	*	(tri)							)	+			
							_FHage3Rtri2		*	(	age**(-3)	*	(tri**(2))						)	+		
							_FHageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FHageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_FHageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FHagesub2R			*	(	age		*	(sub**(-2))							)	+			
							_FHbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FHbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FHbktriR			*	(	bk		*	(tri**(-1))							)	+			
							_FHbmiR				*	(	bmi**(-1)										)	+					
							_FHreact2R			*	(	react**(-2)										)	+					
							_FHresist			*	(	resist											)	+						
							_FHresistR			*	(	resist**(-1)									)	+					
							_FHtri				*	(	tri												)	+						
							_FHtriR				*	(	tri**(-1)										)						
						
					;
	run;	

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODH2;
	RUN;
	
	proc sql;
		create table MOD8 as
		select a.predBIAbf_H, a.ID
		from coefModH as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODH;
	RUN;


	PROC SORT DATA=MOD8;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD8;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD8;
	RUN;

	*********
	*Model I;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModI(drop=_name_ _label_) prefix=_MI;
	    id parameter;
	    var MBIAModI;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModI(drop=_name_ _label_) prefix=_FI;
	    id parameter;
	    var FBIAModI;
	run;
	*Merge "I" data sets;
	proc sql;
		create table coefModI2 as
		select m.*, f.*,
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModI as m, coefFModI as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODI COEFFMODI;
	RUN;

	*Calculate Predicted body fat;
	data coefModI;
		set coefModI2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then

				predBIABF_I= 	
							_MIIntercept		+								
							_MIBMI				*	(	BMI												)	+						
							_MIadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MIageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MIageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MIageRtri			*	(	age**(-1)	*	(tri)							)	+			
							_MIageRwaist3		*	(	age**(-1)	*	(waist**(3))					)	+		
							_MIageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MIagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_MIbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MIbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_MIbkri				*	(	bk		*	(ri)								)	+				
							_MIbkri2			*	(	bk		*	(ri**(2))							)	+			
							_MIbmiR				*	(	bmi**(-1)										)	+					
							_MIreact			*	(	react											)	+						
							_MIreactR			*	(	react**(-1)										)	+					
							_MIresist3			*	(	resist**(3)										)	+					
							_MItri				*	(	tri												)	+						
							_MItriR				*	(	tri**(-1)										)	+					
							_MIwaist			*	(	waist											)							
						

					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_I=	
							_FIIntercept		+								
							_FIBMI				*	(	bmi												)	+						
							_FIadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FIage3Rresist3		*	(age**(-3)	*	(resist**(3))						)	+		
							_FIage3Rtri			*	(age**(-3)	*	(tri)								)	+			
							_FIage3Rwaist3		*	(age**(-3)	*	(waist**(3))						)	+		
							_FIageRbmi2			*	(age**(-1)	*	(bmi**(2))							)	+		
							_FIageRri3			*	(age**(-1)	*	(ri**(3))							)	+		
							_FIageRtri2			*	(age**(-1)	*	(tri**(2))							)	+		
							_FIagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_FIageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FIagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_FIbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FIbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FIbmiR				*	(	bmi**(-1)										)	+					
							_FIreactR			*	(	react**(-1)										)	+					
							_FIresist			*	(	resist											)	+						
							_FIresistR			*	(	resist**(-1)									)	+					
							_FItri				*	(	tri												)	+						
							_FItriR				*	(	tri**(-1)										)	+					
							_FIwaistR			*	(	waist**(-1)										)						
						
	
					;
	run;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODI2;
	RUN;
	
	proc sql;
		create table MOD9 as
		select a.predBIAbf_I, a.ID
		from coefModI as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODI;
	RUN;

	PROC SORT DATA=MOD9;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD9;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD9;
	RUN;

	*********
	*Model J;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModJ(drop=_name_ _label_) prefix=_MJ;
	    id parameter;
	    var MBIAModJ;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModJ(drop=_name_ _label_) prefix=_FJ;
	    id parameter;
	    var FBIAModJ;
	run;
	*Merge "J" data sets;
	proc sql;
		create table coefModJ2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModJ as m, coefFModJ as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODJ COEFFMODJ;
	RUN;

	*Calculate Predicted body fat;
	data coefModJ;
		set coefModJ2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_J= 	
							_MJIntercept		+								
							_MJadage2armc3R		*	(	adult	*	(age**(2))	*	(armc**(-3))		)	+
							_MJadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MJadage3bmi3R		*	(	adult	*	(age**(3))	*	(bmi**(-3))			)	+
							_MJadage3wt3R		*	(	adult	*	(age**(3))	*	(wt**(-3))			)	+
							_MJadht3			*	(	adult	*	(ht**(3))							)	+			
							_MJadwt2			*	(	adult	*	(wt**(2))							)	+			
							_MJage2Rarmc3		*	(	age**(-2)	*	(armc**(3))						)	+		
							_MJage3Rht3R		*	(	age**(-3)	*	(ht**(-3))						)	+		
							_MJage3Rri3R		*	(	age**(-3)	*	(ri**(-3))						)	+		
							_MJage3react3R		*	(	age**(3)	*	(react**(-3))					)	+		
							_MJageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MJageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MJageRwaist2		*	(	age**(-1)	*	(waist**(2))					)	+		
							_MJageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MJagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_MJbkadwt3R			*	(	bk		*	(adult)	*	(wt**(-3))				)	+	
							_MJbkarmc3R			*	(	bk		*	(armc**(-3))						)	+			
							_MJbkbmi3R			*	(	bk		*	(bmi**(-3))							)	+			
							_MJbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MJbkresist3R		*	(	bk		*	(resist**(-3))						)	+			
							_MJbkri2			*	(	bk		*	(ri**(2))							)	+			
							_MJbkwaist3R		*	(	bk		*	(waist**(-3))						)	+			
							_MJbmiR				*	(	bmi**(-1)										)	+					
							_MJht2				*	(ht**(2)											)	+					
							_MJmtadwt3R			*	(	mt		*	(adult)	*	(wt**(-3))				)	+	
							_MJmtri3			*	(	mt		*	(ri**(3))							)	+			
							_MJmxadri3R			*	(	mx		*	(adult)	*	(ri**(-3))				)	+	
							_MJmxreact3			*	(	mx		*	(react**(3))						)	+			
							_MJmxreact3R		*	(	mx		*	(react**(-3))						)	+			
							_MJreact			*	(	react											)	+						
							_MJresist2			*	(	resist**(2)										)	+					
							_MJriR				*	(ri**(-1)											)	+					
							_MJwaist			*	(	waist											)							
						
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B")  then 

				predBIABF_J=	
							_FJIntercept		+								
							_FJBMI				*	(	bmi												)	+						
							_FJadage2Rwt3R		*	(	adult	*	(age**(-2))	*	(wt**(-3))			)	+
							_FJadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FJage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FJage3Rwaist3		*	(	age**(-3)	*	(waist**(3))					)	+		
							_FJageRarmc3		*	(	age**(-1)	*	(armc**(3))						)	+		
							_FJageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_FJageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FJagearmc3R		*	(	age		*	(armc**(-3))						)	+			
							_FJageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FJarmc				*	(	armc											)	+						
							_FJbkarmcR			*	(	bk		*	(armc**(-1))						)	+			
							_FJbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FJbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FJbkri				*	(	bk		*	(ri)								)	+				
							_FJbmiR				*	(	bmi**(-1)										)	+					
							_FJreactR			*	(	react**(-1)										)	+					
							_FJresist			*	(	resist											)	+						
							_FJwaistR			*	(	waist**(-1)										)						
						
					;
	run;	

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODJ2;
	RUN;
	
	proc sql;
		create table MOD10 as
		select a.predBIAbf_J, a.ID
		from coefModJ as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODJ;
	RUN;

	PROC SORT DATA=MOD10;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD10;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD10;
	RUN;

	*********
	*Model K;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModK(drop=_name_ _label_) prefix=_MK;
	    id parameter;
	    var MBIAModK;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModK(drop=_name_ _label_) prefix=_FK;
	    id parameter;
	    var FBIAModK;
	run;
	*Merge "K" data sets;
	proc sql;
		create table coefModK2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModK as m, coefFModK as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODK COEFFMODK;
	RUN;

	*Calculate Predicted body fat;
	data coefModK;
		set coefModK2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_K= 
							_MKIntercept		+								
							_MKBMI				*	(	bmi												)	+						
							_MKadage2armc3R		*	(	adult	*	(age**(2))	*	(armc**(-3))		)	+
							_MKadage3Rarmc3		*	(	adult	*	(age**(-3))	*	(armc**(3))			)	+
							_MKadage3Rbmi2R		*	(	adult	*	(age**(-3))	*	(bmi**(-2))			)	+
							_MKadage3Rbmi3R		*	(	adult	*	(age**(-3))	*	(bmi**(-3))			)	+
							_MKadage3Rresist3	*	(	adult	*	(age**(-3))	*	(resist**(3))		)	+
							_MKadage3Rresist3R	*	(	adult	*	(age**(-3))	*	(resist**(-3))		)	+
							_MKadage3Rwt2R		*	(	adult	*	(age**(-3))	*	(wt**(-2))			)	+
							_MKadagearmc2R		*	(	adult	*	(age)		*	(armc**(-2))		)	+	
							_MKadageht3			*	(	adult	*	(age)		*	(ht**(3))			)	+	
							_MKadageri3			*	(	adult	*	(age)		*	(ri**(3))			)	+	
							_MKadwt2			*	(	adult	*	(wt**(2))							)	+			
							_MKage2Rarmc3		*	(	age**(-2)	*	(armc**(3))						)	+		
							_MKage3Rht3R		*	(	age**(-3)	*	(ht**(-3))						)	+		
							_MKage3Rri3R		*	(	age**(-3)	*	(ri**(-3))						)	+		
							_MKage3react3R		*	(	age**(3)	*	(react**(-3))					)	+		
							_MKageRbmi			*	(	age**(-1)	*	(bmi)							)	+			
							_MKageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_MKageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MKageRresist3R		*	(	age**(-1)	*	(resist**(-3))					)	+		
							_MKageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MKageRwt2			*	(	age**(-1)	*	(wt**(2))						)	+		
							_MKagebmi2R			*	(	age		*	(bmi**(-2))							)	+			
							_MKbkbmiR			*	(	bk		*	(bmi**(-1))							)	+			
							_MKbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MKbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_MKbkresistr		*	(	bk		*	(resist**(-1))						)	+			
							_MKbmiR				*	(	bmi**(-1)										)	+					
							_MKmtadarmc3R		*	(	mt		*	(adult)	*	(armc**(-3))			)	+	
							_MKmtadwt2R			*	(	mt		*	(adult)	*	(wt**(-2))				)	+	
							_MKmtarmc3			*	(	mt		*	(armc**(3))							)	+			
							_MKmtht3			*	(	mt		*	(ht**(3))							)	+			
							_MKmtri3			*	(	mt		*	(ri**(3))							)	+			
							_MKmxadri3			*	(	mx		*	(adult)	*	(ri**(3))				)	+	
							_MKmxadri3R			*	(	mx		*	(adult)	*	(ri**(-3))				)	+	
							_MKmxreact3			*	(	mx		*	(react**(3))						)	+			
							_MKmxreact3R		*	(	mx		*	(react**(-3))						)	+			
							_MKreact			*	(	react											)	+						
							_MKresist			*	(	resist											)	+						
							_MKresist2			*	(	resist**(2)										)	+					
							_MKriR				*	(	ri**(-1)										)						
						
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_K=	
							_FKIntercept		+								
							_FKBMI				*	(	bmi												)	+						
							_FKadage2Rwt3R		*	(	adult	*	(age**(-2))	*	(wt**(-3))			)	+
							_FKage3Rarmc3		*	(	age**(-3)	*	(armc**(3))						)	+		
							_FKage3Rreact3R		*	(	age**(-3)	*	(react**(-3))					)	+		
							_FKage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FKageRarmc3		*	(	age**(-1)	*	(armc**(3))						)	+		
							_FKageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_FKageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FKagearmc3R		*	(	age		*	(armc**(-3))						)	+			
							_FKageresist3		*	(	age		*	(resist**(3))						)	+			
							_FKageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FKarmc				*	(	armc											)	+						
							_FKarmcR			*	(	armc**(-1)										)	+					
							_FKbkarmcR			*	(	bk		*	(armc**(-1))						)	+			
							_FKbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FKbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FKbmiR				*	(	bmi**(-1)										)	+					
							_FKreact			*	(	react											)	+						
							_FKreactR			*	(	react**(-1)										)	+					
							_FKresist			*	(	resist											)	+						
							_FKresistR			*	(	resist**(-1)									)						
							
							;
	run;		

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODK2;
	RUN;

	proc sql;
		create table MOD11 as
		select a.predBIAbf_K, a.ID
		from coefModK as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODK;
	RUN;


	PROC SORT DATA=MOD11;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD11;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD11;
	RUN;

	*********
	*Model L;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModL(drop=_name_ _label_) prefix=_ML;
	    id parameter;
	    var MBIAModL;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModL(drop=_name_ _label_) prefix=_FL;
	    id parameter;
	    var FBIAModL;
	run;
	*Merge "L" data sets;
	proc sql;
		create table coefModL2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT,
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModL as m, coefFModL as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODL COEFFMODL;
	RUN;

	*Calculate Predicted body fat;
	data coefModL;
		set coefModL2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_L= 	
							_MLIntercept		+								
							_MLadage3Rresist3	*	(	adult	*	(age**(-3))	*	(resist**(3))		)	+
							_MLadage3Rwaist3R	*	(	adult	*	(age**(-3))	*	(waist**(-3))		)	+
							_MLadage3wt3R		*	(	adult	*	(age**(3))	*	(wt**(-3))			)	+
							_MLadageht3			*	(	adult	*	(age)		*	(ht**(3))			)	+
							_MLadht3			*	(	adult	*	(ht**(3))							)	+			
							_MLadwt2			*	(	adult	*	(wt**(2))							)	+			
							_MLage3Rht3R		*	(	age**(-3)	*	(ht**(-3))						)	+		
							_MLage3Rri3R		*	(	age**(-3)	*	(ri**(-3))						)	+		
							_MLage3Rwt2R		*	(	age**(-3)	*	(wt**(-2))						)	+		
							_MLageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_MLageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MLageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MLageRwaist2		*	(	age**(-1)	*	(waist**(2))					)	+		
							_MLageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MLagewaist3R		*	(	age		*	(waist**(-3))						)	+			
							_MLbkadwt3R			*	(	bk		*	(adult)	*	(wt**(-3))				)	+	
							_MLbkbmi3R			*	(	bk		*	(bmi**(-3))							)	+			
							_MLbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MLbkresist3R		*	(	bk		*	(resist**(-3))						)	+			
							_MLbkri2			*	(	bk		*	(ri**(2))							)	+			
							_MLbkwaist3R		*	(	bk		*	(waist**(-3))						)	+			
							_MLbmiR				*	(	bmi**(-1)										)	+					
							_MLht2				*	(	ht**(2)											)	+					
							_MLmtadwt3R			*	(	mt		*	(adult)	*	(wt**(-3))				)	+	
							_MLmtri3			*	(	mt		*	(ri**(3))							)	+			
							_MLmxadri3R			*	(	mx		*	(adult)	*	(ri**(-3))				)	+	
							_MLmxreact3			*	(	mx		*	(react**(3))						)	+			
							_MLmxreact3R		*	(	mx		*	(react**(-3))						)	+			
							_MLreact			*	(	react											)	+						
							_MLresist			*	(	resist											)	+						
							_MLresist2			*	(	resist**(2)										)	+					
							_MLwaist			*	(	waist											)							
						
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_L=	
							_FLIntercept		+								
							_FLBMI				*	(	bmi												)	+						
							_FLadage2Rwt3R		*	(	adult	*	(age**(-2))	*	(wt**(-3))			)	+
							_FLadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FLage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FLage3RriR			*	(	age**(-3)	*	(ri**(-1))						)	+		
							_FLage3Rwaist3		*	(	age**(-3)	*	(waist**(3))					)	+		
							_FLageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_FLageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FLagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_FLageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FLbkbmiR			*	(	bk		*	(bmi**(-1))							)	+			
							_FLbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FLbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FLbmiR				*	(	bmi**(-1)										)	+					
							_FLreactR			*	(	react**(-1)										)	+					
							_FLresist			*	(	resist											)	+						
							_FLwaistR			*	(	waist**(-1)										)						
							
					;
	run;	

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODL2;
	RUN;
	
	proc sql;
		create table MOD12 as
		select a.predBIAbf_L, a.ID
		from coefModL as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODL;
	RUN;


	PROC SORT DATA=MOD12;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD12;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD12;
	RUN;

	*********
	*Model M;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModM(drop=_name_ _label_) prefix=_MM;
	    id parameter;
	    var MBIAModM;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModM(drop=_name_ _label_) prefix=_FM;
	    id parameter;
	    var FBIAModM;
	run;
	*Merge "M" data sets;
	proc sql;
		create table coefModM2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModM as m, coefFModM as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODM COEFFMODM;
	RUN;

	*Calculate Predicted body fat;
	data coefModM;
		set coefModM2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_M= 	
							_MMIntercept		+								
							_MMBMI				*	(	bmi												)	+						
							_MMadage3Rwt2R		*	(	adult	*	(age**(-3))	*	(wt**(-2))			)	+
							_MMadage3Rwt3R		*	(	adult	*	(age**(-3))	*	(wt**(-3))			)	+
							_MMadagewt3			*	(	adult	*	(age)	*	(wt**(3))				)	+	
							_MMageRbmi2			*	(	age**(-1)	*	(bmi**	(2))					)	+		
							_MMageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MMageRresist3R		*	(	age**(-1)	*	(resist**(-3))					)	+		
							_MMageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MMageRtri			*	(	age**(-1)	*	(tri)							)	+			
							_MMagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_MMageresist3		*	(	age		*	(resist**(3))						)	+			
							_MMageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MMbkreact2			*	(	bk		*	(react**(2))						)	+			
							_MMbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_MMreactR			*	(	react**(-1)										)	+					
							_MMresist			*	(	resist											)	+						
							_MMresist2			*	(	resist**(2)										)	+					
							_MMtri				*	(	tri												)	+						
							_MMtriR				*	(	tri**(-1)										)						
							

						;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_M=	
							_FMIntercept		+								
							_FMBMI				*	(	bmi												)	+						
							_FMadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FMage3Rbmi3		*	(	age**(-3)	*	(bmi**(3))						)	+		
							_FMage3Rtri			*	(	age**(-3)	*	(tri)							)	+			
							_FMage3Rtri2		*	(	age**(-3)	*	(tri**(2))						)	+		
							_FMageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FMageRtri2			*	(	age**(-1)	*	(tri**(2))						)	+		
							_FMagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_FMageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FMbkreact2			*	(	bk		*	(react**(2))						)	+			
							_FMbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FMbmiR				*	(	bmi**(-1)										)	+					
							_FMresist			*	(	resist											)	+						
							_FMresistR			*	(	resist**(-1)									)	+					
							_FMtri				*	(	tri												)	+						
							_FMtriR				*	(	tri**(-1)										)						
							
					;
	run;		

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODM2;
	RUN;
	
	proc sql;
		create table MOD13 as
		select a.predBIAbf_M, a.ID
		from coefModM as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODM;
	RUN;

	PROC SORT DATA=MOD13;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD13;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD13;
	RUN;

	*********
	*Model N;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModN(drop=_name_ _label_) prefix=_MN;
	    id parameter;
	    var MBIAModN;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModN(drop=_name_ _label_) prefix=_FN;
	    id parameter;
	    var FBIAModN;
	run;
	*Merge "N" data sets;
	proc sql;
		create table coefModN2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModN as m, coefFModN as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODN COEFFMODN;
	RUN;

	*Calculate Predicted body fat;
	data coefModN;
		set coefModN2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_N= 	
							_MNIntercept		+								
							_MNBMI				*	(	bmi												)	+						
							_MNadage3Rbmi3R		*	(	adult	*	(age**(-3))	*	(bmi**(-3))			)	+
							_MNadage3Rresist3R	*	(	adult	*	(age**(-3))	*	(resist**(-3))		)	+
							_MNadage3Rwt2R		*	(	adult	*	(age**(-3))	*	(wt**(-2))			)	+
							_MNadageht3			*	(	adult	*	(age)		*	(ht**(3))			)	+	
							_MNadagewt2			*	(	adult	*	(age)		*	(wt**(2))			)	+	
							_MNadwt2			*	(	adult	*	(wt**(2))							)	+			
							_MNage2Rwt2			*	(	age**(-2)	*	(wt**(2))						)	+		
							_MNage3Rwt2			*	(	age**(-3)	*	(wt**(2))						)	+		
							_MNageRbmi			*	(	age**(-1)	*	(bmi)							)	+			
							_MNageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_MNageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MNageRresist3R		*	(	age**(-1)	*	(resist**(-3))					)	+		
							_MNageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MNagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_MNageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MNbkbmiR			*	(	bk		*	(bmi**(-1))							)	+			
							_MNbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MNbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_MNbmiR				*	(	bmi**(-1)										)	+					
							_MNmtadri3R			*	(	mt		*	(adult)	*	(ri**(-3))				)	+	
							_MNmtadwt3R			*	(	mt		*	(adult)	*	(wt**(-3))				)	+	
							_MNmtri3			*	(	mt		*	(ri**(3))							)	+			
							_MNmxadri3R			*	(	mx		*	(adult)	*	(ri**(-3))				)	+	
							_MNmxreact3			*	(	mx		*	(react**(3))						)	+			
							_MNmxreact3R		*	(	mx		*	(react**(-3))						)	+			
							_MNreact			*	(	react											)	+						
							_MNresist			*	(	resist											)	+						
							_MNresist2			*	(	resist**(2)										)						
							
				;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_N=	
							_FNIntercept		+								
							_FNBMI				*	(	bmi												)	+						
							_FNadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FNage3Rbmi3		*	(	age**(-3)	*	(bmi**(3))						)	+		
							_FNage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FNageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FNagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_FNageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FNbkbmiR			*	(	bk		*	(bmi**(-1))							)	+			
							_FNbmiR				*	(	bmi**(-1)										)	+					
							_FNresist			*	(	resist											)	+						
							_FNresist2			*	(	resist**(2)										)						
						
					;
	run;		

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODN2;
	RUN;

	proc sql;
		create table MOD14 as
		select a.predBIAbf_N, a.ID
		from coefModN as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODN;
	RUN;

	PROC SORT DATA=MOD14;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD14;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD14;
	RUN;

	*********
	*Model O;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModO(drop=_name_ _label_) prefix=_MO;
	    id parameter;
	    var MBIAModO;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModO(drop=_name_ _label_) prefix=_FO;
	    id parameter;
	    var FBIAModO;
	run;
	*Merge "O" data sets;
	proc sql;
		create table coefModO2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModO as m, coefFModO as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODO COEFFMODO;
	RUN;

	*Calculate Predicted body fat;
	data coefModO;
		set coefModO2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_O= 
							_MOIntercept		+								
							_MOBMI				*	(	bmi												)	+						
							_MOadage2ri3		*	(	adult	*	(age**(2))	*	(ri**(3))			)	+
							_MOadage3Rbmi3R		*	(	adult	*	(age**(-3))	*	(bmi**(-3))			)	+
							_MOadage3Rresist3R	*	(	adult	*	(age**(-3))	*	(resist**(-3))		)	+
							_MOadage3Rwt2R		*	(	adult	*	(age**(-3))	*	(wt**(-2))			)	+
							_MOadageht3			*	(	adult	*	(age)		*	(ht**(3))			)	+	
							_MOadagewt2			*	(	adult	*	(age)		*	(wt**(2))			)	+	
							_MOadwt2			*	(	adult	*	(wt**(2))							)	+			
							_MOage3Rleg3		*	(	age**(-3)	*	(leg**(3))						)	+		
							_MOageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_MOageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MOageRresist3R		*	(	age**(-1)	*	(resist**(-3))					)	+		
							_MOageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MOagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_MOarml				*	(	arml											)	+						
							_MOarml2			*	(	arml**(2)										)	+					
							_MObkbmiR			*	(	bk		*	(bmi**(-1))							)	+			
							_MObkleg3R			*	(	bk		*	(leg**(-3))							)	+			
							_MObkreact3			*	(	bk		*	(react**(3))						)	+			
							_MObkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_MObmiR				*	(	bmi**(-1)										)	+					
							_MOleg2				*	(	leg**(2)										)	+					
							_MOleg3				*	(	leg**(3)										)	+					
							_MOmtri3			*	(	mt		*	(ri**(3))							)	+			
							_MOmxadri3R			*	(	mx		*	(adult)	*	(ri**(-3))				)	+	
							_MOmxreact3			*	(	mx		*	(react**(3))						)	+			
							_MOmxreact3R		*	(	mx		*	(react**(-3))						)	+			
							_MOreact			*	(	react											)	+						
							_MOresist			*	(	resist											)	+						
							_MOresist2			*	(	resist**(2)										)						
							
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_O=	
							_FOIntercept		+								
							_FOBMI				*	(	bmi												)	+						
							_FOadage2Rwt3R		*	(	adult	*	(age**(-2))	*	(wt**(-3))			)	+
							_FOadageRwt3R		*	(	adult	*	(age**(-1))	*	(wt**(-3))			)	+
							_FOage3Rbmi2		*	(	age**(-3)	*	(bmi**(2))						)	+		
							_FOage3Rbmi3		*	(	age**(-3)	*	(bmi**(3))						)	+		
							_FOage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FOageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FOagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_FOageresist3		*	(	age		*	(resist**(3))						)	+			
							_FOageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FObkbmiR			*	(	bk		*	(bmi**(-1))							)	+			
							_FObkreact3			*	(	bk		*	(react**(3))						)	+			
							_FObkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FObmiR				*	(	bmi**(-1)										)	+					
							_FOreactR			*	(	react**(-1)										)	+					
							_FOresist			*	(	resist											)							
						
					;
	run;	

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODO2;
	RUN;

	proc sql;
		create table MOD15 as
		select a.predBIAbf_O, a.ID
		from coefModO as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODO;
	RUN;

	PROC SORT DATA=MOD15;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD15;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD15;
	RUN;


	*********
	*Model P;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModP(drop=_name_ _label_) prefix=_MP;
	    id parameter;
	    var MBIAModP;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModP(drop=_name_ _label_) prefix=_FP;
	    id parameter;
	    var FBIAModP;
	run;
	*Merge "P" data sets;
	proc sql;
		create table coefModP2 as
		select m.*, f.*, 
				t.ID, t.SEX, t.AGE, t.ETHNICITY, t.HT, t.WT, t.TRI, t.SUB, t.WAIST, t.CALF, t.ARMC, t.THIC, t.ARML,
				t.LEG, t.MENSES, t.RESIST, t.REACT, 
				(age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
				(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModP as m, coefFModP as f, &usedata as t;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODP COEFFMODP;
	RUN;

	*Calculate Predicted body fat;
	data coefModP;
		set coefModP2;
	
		if upcase(sex)="M" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then

				predBIABF_P= 	
							_MPIntercept		+								
							_MPBMI				*	(	bmi												)	+						
							_MPadage3Rwt2R		*	(	adult	*	(age**(-3))	*	(wt**(-2))			)	+
							_MPadage3Rwt3R		*	(	adult	*	(age**(-3))	*	(wt**(-3))			)	+
							_MPadagewt2			*	(	adult	*	(age)		*	(wt**(2))			)	+	
							_MPadagewt3			*	(	adult	*	(age)		*	(wt**(3))			)	+	
							_MPadwt3			*	(	adult	*	(wt**(3))							)	+			
							_MPageRbmi2			*	(	age**(-1)	*	(bmi**(2))						)	+		
							_MPageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MPageRresist3R		*	(	age**(-1)	*	(resist**(-3))					)	+		
							_MPageRri2			*	(	age**(-1)	*	(ri**(2))						)	+		
							_MPageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_MPageRtri			*	(	age**(-1)	*	(tri)							)	+			
							_MPagebmi3R			*	(	age		*	(bmi**(-3))							)	+			
							_MPageresist3		*	(	age		*	(resist**(3))						)	+			
							_MPageri2R			*	(	age		*	(ri**(-2))							)	+			
							_MPbkreact2			*	(	bk		*	(react**(2))						)	+			
							_MPbkreact3			*	(	bk		*	(react**(3))						)	+			
							_MPbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_MPbkri				*	(	bk		*	(ri)								)	+				
							_MPbmiR				*	(	bmi**(-1)										)	+					
							_MPreact			*	(	react											)	+						
							_MPreactR			*	(	react**(-1)										)	+					
							_MPresist			*	(	resist											)	+						
							_MPresist2			*	(	resist**(2)										)	+					
							_MPsubR				*	(	sub**(-1)										)	+					
							_MPtri				*	(	tri												)	+						
							_MPtriR				*	(	tri**(-1)										)						
							
					;

		else if upcase(sex)="F" AND (upcase(ethnicity) = "W" OR  upcase(ethnicity) = "M" OR upcase(ethnicity) = "O" OR upcase(ethnicity) = "B") then 

				predBIABF_P=	
							_FPIntercept		+								
							_FPBMI				*	(	bmi												)	+						
							_FPadage2Rwt3R		*	(	adult	*	(age**(-2))	*	(wt**(-3))			)	+
							_FPage3Rresist3		*	(	age**(-3)	*	(resist**(3))					)	+		
							_FPage3Rsub			*	(	age**(-3)	*	(sub)							)	+			
							_FPage3Rtri			*	(	age**(-3)	*	(tri)							)	+			
							_FPage3Rtri2		*	(	age**(-3)	*	(tri**(2))						)	+		
							_FPageRri3			*	(	age**(-1)	*	(ri**(3))						)	+		
							_FPageRsub			*	(	age**(-1)	*	(sub)							)	+			
							_FPageri3R			*	(	age		*	(ri**(-3))							)	+			
							_FPagesub2R			*	(	age		*	(sub**(-2))							)	+			
							_FPbkreact3			*	(	bk		*	(react**(3))						)	+			
							_FPbkresist2R		*	(	bk		*	(resist**(-2))						)	+			
							_FPbktriR			*	(	bk		*	(tri**(-1))							)	+			
							_FPbmiR				*	(	bmi**(-1)										)	+					
							_FPreact2R			*	(	react**(-2)										)	+					
							_FPresist			*	(	resist											)	+						
							_FPresistR			*	(	resist**(-1)									)	+					
							_FPtri				*	(	tri												)	+						
							_FPtriR				*	(	tri**(-1)										)						
							
					;		
	
	run;	
	
	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODP2;
	RUN;

	proc sql;
		create table MOD16 as
		select a.predBIAbf_P, a.ID
		from coefModP as a;
	quit;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODP;
	RUN;


	PROC SORT DATA=MOD16;
		BY ID;
	RUN;

	DATA MOD;
		MERGE MOD MOD16;
		BY ID;
	RUN;

	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD16;
	RUN;



	*********
	*Model Q;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModQ(drop=_name_ _label_) prefix=_MQ;
	    id parameter;
	    var MBIAModQ;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModQ(drop=_name_ _label_) prefix=_FQ;
	    id parameter;
	    var FBIAModQ;
	run;
	*Merge "Q" data sets;
	proc sql;
		create table coefModQ2 as
		select m.*, f.*, t.*, (age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
					(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModQ as m, coefFModQ as f, &usedata as t;
	quit;


	** Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODQ COEFFMODQ;
	RUN;

	*Calculate Predicted body fat;
	data coefModQ;
		set coefModQ2;
	
		if upcase(sex)="M" and ethnicity ne "." then

				predBIABF_Q= 	
							_MQIntercept		+							
							_MQadage3Rresist3	*	(	adult	*	(age**(-3))	*	(resist**(3))		)	+
							_MQadageresist2R	*	(	adult	*	(age)		*	(resist**(-2))		)	+	
							_MQadageresistR		*	(	adult	*	(age)		*	(resist**(-1))		)	+	
							_MQadreact2R		*	(	adult	*	(react**(-2))						)	+		
							_MQadresist2R		*	(	adult	*	(resist**(-2))						)	+		
							_MQage2Rreact3R		*	(	age**(-2)	*	(react**(-3))					)	+	
							_MQage3Rri			*	(	age**(-3)	*	(ri)							)	+		
							_MQage3Rri3R		*	(	age**(-3)	*	(ri**(-3))						)	+	
							_MQageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+	
							_MQageRri2			*	(	age**(-1)	*	(ri**(2))						)	+	
							_MQbkreact			*	(	bk		*	(react)								)	+			
							_MQbkreact2			*	(	bk		*	(react**(2))						)	+		
							_MQbkriR			*	(	bk		*	(ri**(-1))							)	+		
							_MQmtadreact3R		*	(	mt		*	(adult)		*	(react**(-3))		)	+
							_MQmxreactR			*	(	mx		*	(react**(-1))						)	+		
							_MQmxriR			*	(	mx		*	(ri**(-1))							)	+		
							_MQreactR			*	(	react**(-1)										)					
							
					;

		else if upcase(sex)="F" and ethnicity ne "." then 

				predBIABF_Q=	
							_FQIntercept		+						
							_FQadreact2R		*	(	adult	*	(react**(-2))						)	+	
							_FQadreact3R		*	(	adult	*	(react**(-3))						)	+	
							_FQageRresist2		*	(	age**(-1)	*	(resist**(2))					)	+
							_FQageresist2R		*	(	age		*	(resist**(-2))						)	+	
							_FQresist			*	(	resist											)	+				
							_FQresistR			*	(	resist**(-1)									)				
							
				;
	
	run;		

	** Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODQ2;
	RUN;

		
	proc sql;
		create table MOD17 as
		select a.predBIAbf_Q, a.id
		from coefModQ as A;
	quit;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODQ;
	RUN;

	PROC SORT DATA=MOD17;
		BY ID;
	RUN;

	DATA MOD; 
		MERGE MOD MOD17;
		BY ID;
	RUN;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD17;
	RUN;




	*********
	*Model R;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModR(drop=_name_ _label_) prefix=_MR;
	    id parameter;
	    var MBIAModR;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModR(drop=_name_ _label_) prefix=_FR;
	    id parameter;
	    var FBIAModR;
	run;
	*Merge "R" data sets;
	proc sql;
		create table coefModR2 as
		select m.*, f.*, t.*, (age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
					(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModR as m, coefFModR as f, &usedata as t;
	quit;


	** Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODR COEFFMODR;
	RUN;

	*Calculate Predicted body fat;
	data coefModR;
		set coefModR2;
	
	if upcase(sex)="M" and ethnicity ne "." then

				predBIABF_R= 	
							_MRIntercept		+								
							_MRadage3Rresist3	*	(	adult	*	(age**(-3))	*	(resist**(3))		)	+
							_MRadageresist2R	*	(	adult	*	(age)		*	(resist**(-2))		)	+	
							_MRadageresistR		*	(	adult	*	(age)		*	(resist**(-1))		)	+	
							_MRadreact2R		*	(	adult	*	(react**(-2))						)	+			
							_MRage3Rreact3R		*	(	age**(-3)	*	(react**(-3))					)	+		
							_MRageRreact3R		*	(	age**(-1)	*	(react**(-3))					)	+		
							_MRbkreact			*	(	bk		*	(react)								)	+				
							_MRbkreact2			*	(	bk		*	(react**(2))						)	+			
							_MRmxreactR			*	(	mx		*	(react**(-1))						)	+			
							_MRreact2R			*	(	react**(-2)										)	+					
							_MRreactR			*	(	react**(-1)										)						
							

					;

		else if upcase(sex)="F" and ethnicity ne "." then 

				predBIABF_R=	
							_FRIntercept		+					
							_FRadreact3R		*	(	adult	*	(react**(-3))						)	+
							_FRageresist2R		*	(	age		*	(resist**(-2))						)	+
							_FRresist			*	(	resist											)	+			
							_FRresistR			*	(	resist**(-1)									)			
							

					;
	
	run;			

	** Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODR2;
	RUN;

		
	proc sql;
		create table MOD18 as
		select a.predBIAbf_R, a.id
		from coefModR as A;
	quit;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODR;
	RUN;

	PROC SORT DATA=MOD18;
		BY ID;
	RUN;

	DATA MOD; 
		MERGE MOD MOD18;
		BY ID;
	RUN;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD18;
	RUN;



	*********
	*Model S;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModS(drop=_name_ _label_) prefix=_MS;
	    id parameter;
	    var MBIAModS;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModS(drop=_name_ _label_) prefix=_FS;
	    id parameter;
	    var FBIAModS;
	run;
	*Merge "S" data sets;
	proc sql;
		create table coefModS2 as
		select m.*, f.*, t.*, (age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
					(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModS as m, coefFModS as f, &usedata as t;
	quit;


	** Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODS COEFFMODS;
	RUN;


	*Calculate Predicted body fat;
	data coefModS;
		set coefModS2;
	
		if upcase(sex)="M" and ethnicity ne "." then

				predBIABF_S= 	
							_MSIntercept		+			
							_MSreactR			*	(	react**(-1)										)	+
							_MSriR				*	(	ri**(-1)										)	
							

			;

		else if upcase(sex)="F" and ethnicity ne "." then 

				predBIABF_S=	
							_FSIntercept		+		
							_FSresistR			*	(	resist**(-1)									)
							
		;
	
	run;				

	** Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODS2;
	RUN;

		
	proc sql;
		create table MOD19 as
		select a.predBIAbf_S, a.id
		from coefModS as A;
	quit;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODS;
	RUN;

	PROC SORT DATA=MOD19;
		BY ID;
	RUN;

	DATA MOD; 
		MERGE MOD MOD19;
		BY ID;
	RUN;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD19;
	RUN;



	*********
	*Model T;
	*********
	*Males;
	proc transpose data=coefMod out=coefMModT(drop=_name_ _label_) prefix=_MT;
	    id parameter;
	    var MBIAModT;
	run;
	*Females;
	proc transpose data=coefMod out=coefFModT(drop=_name_ _label_) prefix=_FT;
	    id parameter;
	    var FBIAModT;
	run;
	*Merge "S" data sets;
	proc sql;
		create table coefModT2 as
		select m.*, f.*, t.*, (age>=20) as adult, round(wt/((ht/100)**2),0.01) as bmi, (compress(upcase(ethnicity))="B") as bk, 
					(compress(upcase(ethnicity))="M") as mx, (compress(upcase(ethnicity))="O") as mt, ((ht**2)/resist) as ri
		from coefMModT as m, coefFModT as f, &usedata as t;
	quit;


	** Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMMODT COEFFMODT;
	RUN;


	*Calculate Predicted body fat;
	data coefModT;
		set coefModT2;
	
		if upcase(sex)="M" and ethnicity ne "." then

				predBIABF_T= 	
							_MTIntercept		+		
							_MTreactR			*	(	react**(-1)										)
							

			;

		else if upcase(sex)="F" and ethnicity ne "." then 

				predBIABF_T=
							_FTIntercept		+		
							_FTresistR			*	(	resist**(-1)									)
							

		;
	
	run;	

	** Delete temporary data sets**;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODT2;
	RUN;

		
	proc sql;
		create table MOD20 as
		select a.predBIAbf_T, a.id
		from coefModT as A;
	quit;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE COEFMODT;
	RUN;

	PROC SORT DATA=MOD20;
		BY ID;
	RUN;

	DATA MOD; 
		MERGE MOD MOD20;
		BY ID;
	RUN;


	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MOD20 COEFMOD;
	RUN;

	DATA macrolib.PREDBIABFDATA;
		MERGE &USEDATA MOD;
		BY ID;
	RUN;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE mod;
	RUN;


data makedata;
		set macrolib.predBIAbfdata(keep=
		%if &chkAge^=0 	%then %do;	age   %end;
		%if &chkHt^=0 	%then %do;	ht    %end;
		%if &chkWt^=0 	%then %do;	wt    %end;
		%if &chkArml^=0 %then %do;	arml  %end;
		%if &chkLeg^=0 	%then %do;	leg   %end;
		%if &chkArmc^=0 %then %do;	armc  %end;
		%if &chkWaist^=0 %then %do; waist %end;
		%if &chkCalf^=0 %then %do;	calf  %end;
		%if &chkThic^=0 %then %do;	thic  %end;
		%if &chkTri^=0 	%then %do;	tri   %end;
		%if &chkSub^=0 	%then %do;	sub   %end;
		);
	run;
	
	proc means data = makedata maxdec=0 NOPRINT;
		output out=_a;
	run;
	
	data _a;
		set _a(where=(_STAT_="MEAN"));
		%if &chkAge^=0 	%then %do;	chkAgeUnit = (8<=age<=49); %end;
		%if &chkHt^=0 	%then %do;	chkHtUnit = (127<=ht<=177); %end;
		%if &chkWt^=0 	%then %do;	chkWtUnit = (25<=wt<=106); %end;
		%if &chkArml^=0 %then %do;	chkArmlUnit = (26<=arml<=41); %end;
		%if &chkLeg^=0 	%then %do;	chkLegUnit = (29<=leg<=46); %end;
		%if &chkArmc^=0 %then %do;	chkArmcUnit = (18<=armc<=40); %end;
		%if &chkWaist^=0 %then %do; chkWaistUnit = (55<=waist<=120); %end;
		%if &chkCalf^=0 %then %do;	chkCalfUnit = (25<=calf<=47); %end;
		%if &chkThic^=0 %then %do;	chkThicUnit = (34<=thic<=67); %end;
		%if &chkTri^=0 	%then %do;	chkTriUnit = (7<=tri<=38); %end;
		%if &chkSub^=0 	%then %do;	chkSubUnit = (5<=sub<=38); %end;
	run;

	data _null_;
		set _a;
		call symput('chkAgeUnit', 	chkAgeUnit);
		call symput('chkHtUnit',	chkHtUnit);
		call symput('chkWtUnit',	chkWtUnit);
		call symput('chkArmlUnit',	chkArmlUnit);
		call symput('chkLegUnit',   chkLegUnit);
		call symput('chkArmcUnit', 	chkArmcUnit);
		call symput('chkWaistUnit', chkWaistUnit);
		call symput('chkCalfUnit', 	chkCalfUnit);
		call symput('chkThicUnit', 	chkThicUnit);
		call symput('chkTriUnit', 	chkTriUnit);
		call symput('chkSubUnit', 	chkSubUnit);
	run;

	** Delete temporary data sets **;
	PROC DATASETS LIBRARY=WORK NOLIST;
		DELETE MAKEDATA _A;
	RUN;
	QUIT;

		%if &chkAgeUnit=0 	%then %put WARNING: Variable AGE is out-of-range [8, 49]. ;
		%if &chkEthnicityUnit=0 	%then %put WARNING: Variable ETHNICITY is out-of-range [W, B, M, O] ;
		%if &chkHtUnit=0 	%then %put WARNING: Variable HT is out-of-range [127, 177].;
		%if &chkWtUnit=0 	%then %put WARNING: Variable WT is out-of-range [25, 106].;
		%if &chkArmlUnit=0 	%then %put WARNING: Variable ARML is out-of-range [26, 41].;
		%if &chkLegUnit=0 	%then %put WARNING: Variable LEG is out-of-range [29, 46].;
		%if &chkArmcUnit=0 	%then %put WARNING: Variable ARMC is out-of-range [18, 40].;
		%if &chkWaistUnit=0 %then %put WARNING: Variable WAIST is out-of-range [55, 120].;
		%if &chkCalfUnit=0 	%then %put WARNING: Variable CALF is out-of-range [25, 47].;
		%if &chkThicUnit=0 	%then %put WARNING: Variable THIC is out-of-range [34, 67].;
		%if &chkTriUnit=0 	%then %put WARNING: Variable TRI is out-of-range [7, 38].;
		%if &chkSubUnit=0 	%then %put WARNING: Variable SUB is out-of-range [5, 38].;
		%if %upcase(sex)=F %then %do;
			%if &chkMensesUnit=0 	%then %put WARNING: Variable MENSES is out-of-range [0, 1] ;
		%end;



%exit: 
%mend calcPredBIA;


